@@ -4,6 +4,7 @@
 }
 
 .onAttach <- function(...) {
+### This was giving troubles with cyclic dependencies so is removed
   ## initialize toolkit if not there
-  guiToolkit()
+  ##guiToolkit()
 }
